import pyfie
import matplotlib.pyplot as plt

# 利便のため PyFIE 関数が返すエラーコードに応じて例外を発生させる機能を有効化
pyfie.ctrl.enable_f_err_exception(True)

# パターン画像読み込み
pattern = pyfie.imread("gs_pattern.png")

# 処理対象画像読み込み
target = pyfie.imread("gs_target.png")

# グレイサーチパターンオブジェクトの生成
gs_pattern = pyfie.fnFIE_gs2_pattern_alloc(
    pattern, None, pattern.width / 2 * 100, pattern.height / 2 * 100,
    pyfie.F_COMP_MODE_SMOOTH, None
)

# グレイサーチオブジェクトの生成
hgs = pyfie.fnFIE_gs2_alloc(0, 0, 0)

# サーチウインドウの生成
search_window = pyfie.BOX_T((0, 0), (target.width - 1, target.height - 1))

# サーチ結果の保存先を生成
max_result_num = 5
result = pyfie.F_GS_RESULT.ARRAY(max_result_num)
result_num = pyfie.INT()

# グレイサーチの実行
pyfie.fnFIE_gs2_search_enforce2(
    hgs,  # グレイサーチオブジェクト
    gs_pattern,  # グレイサーチパターンオブジェクト
    target,  # サーチ対象となる画像オブジェクト
    search_window,  # サーチウインドウ
    5000,  # 途中相関値
    6000,  # 最終相関値
    False,  # サーチウインドウ周囲接触フラグ
    False,  # 反転パターン検出モードフラグ
    0,  # 同一解範囲幅
    0,  # 同一解範囲高さ
    2,  # サーチ開始圧縮度
    0,  # サーチ終了圧縮度
    pyfie.F_GS2_SUBPXL_NEIB_8,  # 近傍
    result,  # サーチ結果
    max_result_num,  # サーチ結果取得個数
    result_num  # サーチ結果の個数
)
# サーチ結果個数の表示
print("result number =", result_num)

# サーチ結果の表示
for i in range(result_num):
    print("#{}: x = {}, y = {}, score = {}".format(i, result[i].x / 100,
          result[i].y / 100, result[i].score))

# 画像オブジェクトのプロット
target.imshow()
# 結果をプロット
pyfie.mpltools.plot_gs2_results(gs_pattern, result, result_num)
# 結果をプロットした画像の保存
plt.savefig("gs_result.png")
# 結果をプロットした画像の表示
pyfie.plot_show()
